# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_useraccount.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_useraccount.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_useraccount.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"P\n8CUserAccount_GetAvailableValveDiscountPromotions_Request\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\"\x85\x04\n9CUserAccount_GetAvailableValveDiscountPromotions_Response\x12l\n\npromotions\x18\x01 \x03(\x0b\x32X.CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails\x1a\xd9\x02\n\x1dValveDiscountPromotionDetails\x12\x13\n\x0bpromotionid\x18\x01 \x01(\r\x12\x1d\n\x15promotion_description\x18\x02 \x01(\t\x12\x1b\n\x13minimum_cart_amount\x18\x03 \x01(\x03\x12\'\n\x1fminimum_cart_amount_for_display\x18\x04 \x01(\x03\x12\x17\n\x0f\x64iscount_amount\x18\x05 \x01(\x03\x12\x15\n\rcurrency_code\x18\x06 \x01(\x05\x12\x1b\n\x13\x61vailable_use_count\x18\x07 \x01(\x05\x12!\n\x19promotional_discount_type\x18\x08 \x01(\x05\x12\x19\n\x11loyalty_reward_id\x18\t \x01(\x05\x12\x1c\n\x14localized_name_token\x18\n \x01(\t\x12\x15\n\rmax_use_count\x18\x0b \x01(\x05\"\x8a\x01\n+CUserAccount_GetClientWalletDetails_Request\x12\x1e\n\x16include_balance_in_usd\x18\x01 \x01(\x08\x12\x18\n\rwallet_region\x18\x02 \x01(\x05:\x01\x31\x12!\n\x19include_formatted_balance\x18\x03 \x01(\x08\"\x93\x03\n&CUserAccount_GetWalletDetails_Response\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x19\n\x11user_country_code\x18\x02 \x01(\t\x12\x1b\n\x13wallet_country_code\x18\x03 \x01(\t\x12\x14\n\x0cwallet_state\x18\x04 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x05 \x01(\x03\x12\x17\n\x0f\x64\x65layed_balance\x18\x06 \x01(\x03\x12\x15\n\rcurrency_code\x18\x07 \x01(\x05\x12\x1c\n\x14time_most_recent_txn\x18\x08 \x01(\r\x12\x19\n\x11most_recent_txnid\x18\t \x01(\x04\x12\x16\n\x0e\x62\x61lance_in_usd\x18\n \x01(\x03\x12\x1e\n\x16\x64\x65layed_balance_in_usd\x18\x0b \x01(\x03\x12#\n\x1bhas_wallet_in_other_regions\x18\x0c \x01(\x08\x12\x15\n\rother_regions\x18\r \x03(\x05\x12\x19\n\x11\x66ormatted_balance\x18\x0e \x01(\t\"+\n)CUserAccount_GetAccountLinkStatus_Request\"}\n*CUserAccount_GetAccountLinkStatus_Response\x12\x0c\n\x04pwid\x18\x01 \x01(\r\x12\x1d\n\x15identity_verification\x18\x02 \x01(\r\x12\"\n\x1aperformed_age_verification\x18\x03 \x01(\x08\"9\n(CUserAccount_CancelLicenseForApp_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"+\n)CUserAccount_CancelLicenseForApp_Response\"6\n#CUserAccount_GetUserCountry_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"7\n$CUserAccount_GetUserCountry_Response\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\"r\n,CUserAccount_CreateFriendInviteToken_Request\x12\x14\n\x0cinvite_limit\x18\x01 \x01(\r\x12\x17\n\x0finvite_duration\x18\x02 \x01(\r\x12\x13\n\x0binvite_note\x18\x03 \x01(\t\"\x99\x01\n-CUserAccount_CreateFriendInviteToken_Response\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\x12\x14\n\x0cinvite_limit\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\x12\x14\n\x0ctime_created\x18\x04 \x01(\x07\x12\r\n\x05valid\x18\x05 \x01(\x08\",\n*CUserAccount_GetFriendInviteTokens_Request\"m\n+CUserAccount_GetFriendInviteTokens_Response\x12>\n\x06tokens\x18\x01 \x03(\x0b\x32..CUserAccount_CreateFriendInviteToken_Response\"S\n*CUserAccount_ViewFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"f\n+CUserAccount_ViewFriendInviteToken_Response\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0finvite_duration\x18\x03 \x01(\x04\"U\n,CUserAccount_RedeemFriendInviteToken_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0cinvite_token\x18\x02 \x01(\t\"/\n-CUserAccount_RedeemFriendInviteToken_Response\"D\n,CUserAccount_RevokeFriendInviteToken_Request\x12\x14\n\x0cinvite_token\x18\x01 \x01(\t\"/\n-CUserAccount_RevokeFriendInviteToken_Response\">\n\'CUserAccount_RegisterCompatTool_Request\x12\x13\n\x0b\x63ompat_tool\x18\x01 \x01(\r\"*\n(CUserAccount_RegisterCompatTool_Response\"\x9c\x03\n,CAccountLinking_GetLinkedAccountInfo_Request\x12H\n\x0c\x61\x63\x63ount_type\x18\x01 \x01(\x0e\x32\x15.EInternalAccountType:\x1bk_EInternalSteamAccountType\x12+\n\naccount_id\x18\x02 \x01(\x04\x42\x17\x82\xb5\x18\x13Internal account ID\x12t\n\x06\x66ilter\x18\x03 \x01(\x0e\x32\x15.EExternalAccountType:\x0fk_EExternalNoneB<\x82\xb5\x18\x38if specified then only return this external account type\x12\x7f\n\x13return_access_token\x18\x04 \x01(\x08\x42\x62\x82\xb5\x18^if provided and true, then returns valid access token if available. It may refresh the token. \"\x8b\x06\n-CAccountLinking_GetLinkedAccountInfo_Response\x12h\n\x11\x65xternal_accounts\x18\x01 \x03(\x0b\x32M.CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response\x1a\xef\x04\n\x1e\x43\x45xternalAccountTuple_Response\x12=\n\rexternal_type\x18\x01 \x01(\x0e\x32\x15.EExternalAccountType:\x0fk_EExternalNone\x12;\n\x0b\x65xternal_id\x18\x02 \x01(\tB&\x82\xb5\x18\"unique external account identifier\x12:\n\x12\x65xternal_user_name\x18\x03 \x01(\tB\x1e\x82\xb5\x18\x1auser readable; best effort\x12S\n\x0c\x65xternal_url\x18\x04 \x01(\tB=\x82\xb5\x18\x39required for all, can be a sentinal to verify correctness\x12@\n\x0c\x61\x63\x63\x65ss_token\x18\x05 \x01(\tB*\x82\xb5\x18&provided if requeest and it was valid.\x12k\n\x13\x61\x63\x63\x65ss_token_secret\x18\x06 \x01(\tBN\x82\xb5\x18Jrequired for OAuth v1 and signing the message, provided with access token.\x12\x90\x01\n\x08is_valid\x18\x07 \x01(\x08\x42~\x82\xb5\x18zIf false, it means access token no longer work (expired, disconnected) and the link is now broken. Inform user to refresh.\"w\n.CEmbeddedClient_AuthorizeCurrentDevice_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_info\x18\x03 \x01(\t\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"`\n\x15\x43\x45mbeddedClient_Token\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x63lient_token\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65viceid\x18\x04 \x01(\r\"a\n(CEmbeddedClient_AuthorizeDevice_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12%\n\x05token\x18\x02 \x01(\x0b\x32\x16.CEmbeddedClient_Token*\x8d\x01\n\x14\x45InternalAccountType\x12\x1f\n\x1bk_EInternalSteamAccountType\x10\x01\x12\x17\n\x13k_EInternalClanType\x10\x02\x12\x16\n\x12k_EInternalAppType\x10\x03\x12#\n\x1fk_EInternalBroadcastChannelType\x10\x04*\x86\x02\n\x14\x45\x45xternalAccountType\x12\x13\n\x0fk_EExternalNone\x10\x00\x12\x1b\n\x17k_EExternalSteamAccount\x10\x01\x12\x1c\n\x18k_EExternalGoogleAccount\x10\x02\x12\x1e\n\x1ak_EExternalFacebookAccount\x10\x03\x12\x1d\n\x19k_EExternalTwitterAccount\x10\x04\x12\x1c\n\x18k_EExternalTwitchAccount\x10\x05\x12$\n k_EExternalYouTubeChannelAccount\x10\x06\x12\x1b\n\x17k_EExternalFacebookPage\x10\x07\x32\xc1\x0f\n\x0bUserAccount\x12\xe0\x01\n#GetAvailableValveDiscountPromotions\x12\x39.CUserAccount_GetAvailableValveDiscountPromotions_Request\x1a:.CUserAccount_GetAvailableValveDiscountPromotions_Response\"B\x82\xb5\x18>Gets the available promotional discounts available to the user\x12\xa7\x01\n\x16GetClientWalletDetails\x12,.CUserAccount_GetClientWalletDetails_Request\x1a\'.CUserAccount_GetWalletDetails_Response\"6\x82\xb5\x18\x32Returns balance and details about any users wallet\x12\x90\x01\n\x14GetAccountLinkStatus\x12*.CUserAccount_GetAccountLinkStatus_Request\x1a+.CUserAccount_GetAccountLinkStatus_Response\"\x1f\x82\xb5\x18\x1b\x46\x65tches account link status\x12\x93\x01\n\x13\x43\x61ncelLicenseForApp\x12).CUserAccount_CancelLicenseForApp_Request\x1a*.CUserAccount_CancelLicenseForApp_Response\"%\x82\xb5\x18!Cancels a free license for a user\x12\xc9\x01\n\x0eGetUserCountry\x12$.CUserAccount_GetUserCountry_Request\x1a%.CUserAccount_GetUserCountry_Response\"j\x82\xb5\x18\x66Get the country code associated with the passed steamid (only available for logged-in user or support)\x12\xc4\x01\n\x17\x43reateFriendInviteToken\x12-.CUserAccount_CreateFriendInviteToken_Request\x1a..CUserAccount_CreateFriendInviteToken_Response\"J\x82\xb5\x18\x46\x43reate a limited-use token that can be used to create a friend request\x12\xa1\x01\n\x15GetFriendInviteTokens\x12+.CUserAccount_GetFriendInviteTokens_Request\x1a,.CUserAccount_GetFriendInviteTokens_Response\"-\x82\xb5\x18)Get the set of active tokens for the user\x12\x9b\x01\n\x15ViewFriendInviteToken\x12+.CUserAccount_ViewFriendInviteToken_Request\x1a,.CUserAccount_ViewFriendInviteToken_Response\"\'\x82\xb5\x18#View details about an invite token \x12\xb7\x01\n\x17RedeemFriendInviteToken\x12-.CUserAccount_RedeemFriendInviteToken_Request\x1a..CUserAccount_RedeemFriendInviteToken_Response\"=\x82\xb5\x18\x39\x43reate a friend relationship using the given invite token\x12\xa2\x01\n\x17RevokeFriendInviteToken\x12-.CUserAccount_RevokeFriendInviteToken_Request\x1a..CUserAccount_RevokeFriendInviteToken_Response\"(\x82\xb5\x18$Revoke an active friend invite token\x12\x98\x01\n\x12RegisterCompatTool\x12(.CUserAccount_RegisterCompatTool_Request\x1a).CUserAccount_RegisterCompatTool_Response\"-\x82\xb5\x18)Register intended account usage of a tool\x1a-\x82\xb5\x18)A service to get user account information2\x9d\x02\n\x0e\x41\x63\x63ountLinking\x12\xd3\x01\n\x14GetLinkedAccountInfo\x12-.CAccountLinking_GetLinkedAccountInfo_Request\x1a..CAccountLinking_GetLinkedAccountInfo_Response\"\\\x82\xb5\x18XList all my active linked external accounts; may be requested to return the access token\x1a\x35\x82\xb5\x18\x31\x41 service to manage and link to external accounts2\xa4\x02\n\x0e\x45mbeddedClient\x12\xc1\x01\n\x16\x41uthorizeCurrentDevice\x12/.CEmbeddedClient_AuthorizeCurrentDevice_Request\x1a).CEmbeddedClient_AuthorizeDevice_Response\"K\x82\xb5\x18GUse a logged-in (password/etc) session to create a durable access token\x1aN\x82\xb5\x18JService to authorize and manage Steam functions directly embedded in gamesB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EINTERNALACCOUNTTYPE = _descriptor.EnumDescriptor(
  name='EInternalAccountType',
  full_name='EInternalAccountType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EInternalSteamAccountType', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EInternalClanType', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EInternalAppType', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EInternalBroadcastChannelType', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4130,
  serialized_end=4271,
)
_sym_db.RegisterEnumDescriptor(_EINTERNALACCOUNTTYPE)

EInternalAccountType = enum_type_wrapper.EnumTypeWrapper(_EINTERNALACCOUNTTYPE)
_EEXTERNALACCOUNTTYPE = _descriptor.EnumDescriptor(
  name='EExternalAccountType',
  full_name='EExternalAccountType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EExternalNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalSteamAccount', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalGoogleAccount', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalFacebookAccount', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalTwitterAccount', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalTwitchAccount', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalYouTubeChannelAccount', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EExternalFacebookPage', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4274,
  serialized_end=4536,
)
_sym_db.RegisterEnumDescriptor(_EEXTERNALACCOUNTTYPE)

EExternalAccountType = enum_type_wrapper.EnumTypeWrapper(_EEXTERNALACCOUNTTYPE)
k_EInternalSteamAccountType = 1
k_EInternalClanType = 2
k_EInternalAppType = 3
k_EInternalBroadcastChannelType = 4
k_EExternalNone = 0
k_EExternalSteamAccount = 1
k_EExternalGoogleAccount = 2
k_EExternalFacebookAccount = 3
k_EExternalTwitterAccount = 4
k_EExternalTwitchAccount = 5
k_EExternalYouTubeChannelAccount = 6
k_EExternalFacebookPage = 7



_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_GetAvailableValveDiscountPromotions_Request',
  full_name='CUserAccount_GetAvailableValveDiscountPromotions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Request.country_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=175,
)


_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS = _descriptor.Descriptor(
  name='ValveDiscountPromotionDetails',
  full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='promotionid', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.promotionid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='promotion_description', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.promotion_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_cart_amount', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.minimum_cart_amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_cart_amount_for_display', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.minimum_cart_amount_for_display', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discount_amount', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.discount_amount', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.currency_code', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_use_count', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.available_use_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='promotional_discount_type', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.promotional_discount_type', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loyalty_reward_id', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.loyalty_reward_id', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localized_name_token', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.localized_name_token', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_use_count', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails.max_use_count', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=695,
)

_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_GetAvailableValveDiscountPromotions_Response',
  full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='promotions', full_name='CUserAccount_GetAvailableValveDiscountPromotions_Response.promotions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=695,
)


_CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_GetClientWalletDetails_Request',
  full_name='CUserAccount_GetClientWalletDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_balance_in_usd', full_name='CUserAccount_GetClientWalletDetails_Request.include_balance_in_usd', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet_region', full_name='CUserAccount_GetClientWalletDetails_Request.wallet_region', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_formatted_balance', full_name='CUserAccount_GetClientWalletDetails_Request.include_formatted_balance', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=836,
)


_CUSERACCOUNT_GETWALLETDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_GetWalletDetails_Response',
  full_name='CUserAccount_GetWalletDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_wallet', full_name='CUserAccount_GetWalletDetails_Response.has_wallet', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_country_code', full_name='CUserAccount_GetWalletDetails_Response.user_country_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet_country_code', full_name='CUserAccount_GetWalletDetails_Response.wallet_country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet_state', full_name='CUserAccount_GetWalletDetails_Response.wallet_state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='CUserAccount_GetWalletDetails_Response.balance', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_balance', full_name='CUserAccount_GetWalletDetails_Response.delayed_balance', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='CUserAccount_GetWalletDetails_Response.currency_code', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_most_recent_txn', full_name='CUserAccount_GetWalletDetails_Response.time_most_recent_txn', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_recent_txnid', full_name='CUserAccount_GetWalletDetails_Response.most_recent_txnid', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_in_usd', full_name='CUserAccount_GetWalletDetails_Response.balance_in_usd', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_balance_in_usd', full_name='CUserAccount_GetWalletDetails_Response.delayed_balance_in_usd', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_wallet_in_other_regions', full_name='CUserAccount_GetWalletDetails_Response.has_wallet_in_other_regions', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_regions', full_name='CUserAccount_GetWalletDetails_Response.other_regions', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted_balance', full_name='CUserAccount_GetWalletDetails_Response.formatted_balance', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=1242,
)


_CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_GetAccountLinkStatus_Request',
  full_name='CUserAccount_GetAccountLinkStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1287,
)


_CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_GetAccountLinkStatus_Response',
  full_name='CUserAccount_GetAccountLinkStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pwid', full_name='CUserAccount_GetAccountLinkStatus_Response.pwid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_verification', full_name='CUserAccount_GetAccountLinkStatus_Response.identity_verification', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='performed_age_verification', full_name='CUserAccount_GetAccountLinkStatus_Response.performed_age_verification', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1414,
)


_CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_CancelLicenseForApp_Request',
  full_name='CUserAccount_CancelLicenseForApp_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CUserAccount_CancelLicenseForApp_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1416,
  serialized_end=1473,
)


_CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_CancelLicenseForApp_Response',
  full_name='CUserAccount_CancelLicenseForApp_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1475,
  serialized_end=1518,
)


_CUSERACCOUNT_GETUSERCOUNTRY_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_GetUserCountry_Request',
  full_name='CUserAccount_GetUserCountry_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CUserAccount_GetUserCountry_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1520,
  serialized_end=1574,
)


_CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_GetUserCountry_Response',
  full_name='CUserAccount_GetUserCountry_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='CUserAccount_GetUserCountry_Response.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1576,
  serialized_end=1631,
)


_CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_CreateFriendInviteToken_Request',
  full_name='CUserAccount_CreateFriendInviteToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_limit', full_name='CUserAccount_CreateFriendInviteToken_Request.invite_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_duration', full_name='CUserAccount_CreateFriendInviteToken_Request.invite_duration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_note', full_name='CUserAccount_CreateFriendInviteToken_Request.invite_note', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1633,
  serialized_end=1747,
)


_CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_CreateFriendInviteToken_Response',
  full_name='CUserAccount_CreateFriendInviteToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='CUserAccount_CreateFriendInviteToken_Response.invite_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_limit', full_name='CUserAccount_CreateFriendInviteToken_Response.invite_limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_duration', full_name='CUserAccount_CreateFriendInviteToken_Response.invite_duration', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CUserAccount_CreateFriendInviteToken_Response.time_created', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid', full_name='CUserAccount_CreateFriendInviteToken_Response.valid', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1903,
)


_CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_GetFriendInviteTokens_Request',
  full_name='CUserAccount_GetFriendInviteTokens_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1905,
  serialized_end=1949,
)


_CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_GetFriendInviteTokens_Response',
  full_name='CUserAccount_GetFriendInviteTokens_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CUserAccount_GetFriendInviteTokens_Response.tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2060,
)


_CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_ViewFriendInviteToken_Request',
  full_name='CUserAccount_ViewFriendInviteToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CUserAccount_ViewFriendInviteToken_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='CUserAccount_ViewFriendInviteToken_Request.invite_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2145,
)


_CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_ViewFriendInviteToken_Response',
  full_name='CUserAccount_ViewFriendInviteToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='CUserAccount_ViewFriendInviteToken_Response.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CUserAccount_ViewFriendInviteToken_Response.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_duration', full_name='CUserAccount_ViewFriendInviteToken_Response.invite_duration', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2249,
)


_CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_RedeemFriendInviteToken_Request',
  full_name='CUserAccount_RedeemFriendInviteToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CUserAccount_RedeemFriendInviteToken_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='CUserAccount_RedeemFriendInviteToken_Request.invite_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2336,
)


_CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_RedeemFriendInviteToken_Response',
  full_name='CUserAccount_RedeemFriendInviteToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2338,
  serialized_end=2385,
)


_CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_RevokeFriendInviteToken_Request',
  full_name='CUserAccount_RevokeFriendInviteToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_token', full_name='CUserAccount_RevokeFriendInviteToken_Request.invite_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2387,
  serialized_end=2455,
)


_CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_RevokeFriendInviteToken_Response',
  full_name='CUserAccount_RevokeFriendInviteToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=2504,
)


_CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST = _descriptor.Descriptor(
  name='CUserAccount_RegisterCompatTool_Request',
  full_name='CUserAccount_RegisterCompatTool_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compat_tool', full_name='CUserAccount_RegisterCompatTool_Request.compat_tool', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2568,
)


_CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE = _descriptor.Descriptor(
  name='CUserAccount_RegisterCompatTool_Response',
  full_name='CUserAccount_RegisterCompatTool_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2570,
  serialized_end=2612,
)


_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST = _descriptor.Descriptor(
  name='CAccountLinking_GetLinkedAccountInfo_Request',
  full_name='CAccountLinking_GetLinkedAccountInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_type', full_name='CAccountLinking_GetLinkedAccountInfo_Request.account_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CAccountLinking_GetLinkedAccountInfo_Request.account_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023Internal account ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='CAccountLinking_GetLinkedAccountInfo_Request.filter', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0308if specified then only return this external account type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_access_token', full_name='CAccountLinking_GetLinkedAccountInfo_Request.return_access_token', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030^if provided and true, then returns valid access token if available. It may refresh the token. ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2615,
  serialized_end=3027,
)


_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE = _descriptor.Descriptor(
  name='CExternalAccountTuple_Response',
  full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_type', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.external_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.external_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"unique external account identifier', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_user_name', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.external_user_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\032user readable; best effort', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_url', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.external_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309required for all, can be a sentinal to verify correctness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.access_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030&provided if requeest and it was valid.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_token_secret', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.access_token_secret', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030Jrequired for OAuth v1 and signing the message, provided with access token.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_valid', full_name='CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response.is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030zIf false, it means access token no longer work (expired, disconnected) and the link is now broken. Inform user to refresh.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3186,
  serialized_end=3809,
)

_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE = _descriptor.Descriptor(
  name='CAccountLinking_GetLinkedAccountInfo_Response',
  full_name='CAccountLinking_GetLinkedAccountInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_accounts', full_name='CAccountLinking_GetLinkedAccountInfo_Response.external_accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3030,
  serialized_end=3809,
)


_CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST = _descriptor.Descriptor(
  name='CEmbeddedClient_AuthorizeCurrentDevice_Request',
  full_name='CEmbeddedClient_AuthorizeCurrentDevice_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CEmbeddedClient_AuthorizeCurrentDevice_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEmbeddedClient_AuthorizeCurrentDevice_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_info', full_name='CEmbeddedClient_AuthorizeCurrentDevice_Request.device_info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceid', full_name='CEmbeddedClient_AuthorizeCurrentDevice_Request.deviceid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3811,
  serialized_end=3930,
)


_CEMBEDDEDCLIENT_TOKEN = _descriptor.Descriptor(
  name='CEmbeddedClient_Token',
  full_name='CEmbeddedClient_Token',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CEmbeddedClient_Token.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_token', full_name='CEmbeddedClient_Token.client_token', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='CEmbeddedClient_Token.expiry', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceid', full_name='CEmbeddedClient_Token.deviceid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3932,
  serialized_end=4028,
)


_CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE = _descriptor.Descriptor(
  name='CEmbeddedClient_AuthorizeDevice_Response',
  full_name='CEmbeddedClient_AuthorizeDevice_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CEmbeddedClient_AuthorizeDevice_Response.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='CEmbeddedClient_AuthorizeDevice_Response.token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4030,
  serialized_end=4127,
)

_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS.containing_type = _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE
_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE.fields_by_name['promotions'].message_type = _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS
_CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE.fields_by_name['tokens'].message_type = _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST.fields_by_name['account_type'].enum_type = _EINTERNALACCOUNTTYPE
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST.fields_by_name['filter'].enum_type = _EEXTERNALACCOUNTTYPE
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['external_type'].enum_type = _EEXTERNALACCOUNTTYPE
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.containing_type = _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE.fields_by_name['external_accounts'].message_type = _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE
_CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE.fields_by_name['token'].message_type = _CEMBEDDEDCLIENT_TOKEN
DESCRIPTOR.message_types_by_name['CUserAccount_GetAvailableValveDiscountPromotions_Request'] = _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_GetAvailableValveDiscountPromotions_Response'] = _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_GetClientWalletDetails_Request'] = _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_GetWalletDetails_Response'] = _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_GetAccountLinkStatus_Request'] = _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_GetAccountLinkStatus_Response'] = _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_CancelLicenseForApp_Request'] = _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_CancelLicenseForApp_Response'] = _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_GetUserCountry_Request'] = _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_GetUserCountry_Response'] = _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_CreateFriendInviteToken_Request'] = _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_CreateFriendInviteToken_Response'] = _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_GetFriendInviteTokens_Request'] = _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_GetFriendInviteTokens_Response'] = _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_ViewFriendInviteToken_Request'] = _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_ViewFriendInviteToken_Response'] = _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_RedeemFriendInviteToken_Request'] = _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_RedeemFriendInviteToken_Response'] = _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_RevokeFriendInviteToken_Request'] = _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_RevokeFriendInviteToken_Response'] = _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CUserAccount_RegisterCompatTool_Request'] = _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST
DESCRIPTOR.message_types_by_name['CUserAccount_RegisterCompatTool_Response'] = _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE
DESCRIPTOR.message_types_by_name['CAccountLinking_GetLinkedAccountInfo_Request'] = _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST
DESCRIPTOR.message_types_by_name['CAccountLinking_GetLinkedAccountInfo_Response'] = _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CEmbeddedClient_AuthorizeCurrentDevice_Request'] = _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST
DESCRIPTOR.message_types_by_name['CEmbeddedClient_Token'] = _CEMBEDDEDCLIENT_TOKEN
DESCRIPTOR.message_types_by_name['CEmbeddedClient_AuthorizeDevice_Response'] = _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE
DESCRIPTOR.enum_types_by_name['EInternalAccountType'] = _EINTERNALACCOUNTTYPE
DESCRIPTOR.enum_types_by_name['EExternalAccountType'] = _EEXTERNALACCOUNTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CUserAccount_GetAvailableValveDiscountPromotions_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_GetAvailableValveDiscountPromotions_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetAvailableValveDiscountPromotions_Request)
  })
_sym_db.RegisterMessage(CUserAccount_GetAvailableValveDiscountPromotions_Request)

CUserAccount_GetAvailableValveDiscountPromotions_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_GetAvailableValveDiscountPromotions_Response', (_message.Message,), {

  'ValveDiscountPromotionDetails' : _reflection.GeneratedProtocolMessageType('ValveDiscountPromotionDetails', (_message.Message,), {
    'DESCRIPTOR' : _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE_VALVEDISCOUNTPROMOTIONDETAILS,
    '__module__' : 'steammessages_useraccount_pb2'
    # @@protoc_insertion_point(class_scope:CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails)
    })
  ,
  'DESCRIPTOR' : _CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetAvailableValveDiscountPromotions_Response)
  })
_sym_db.RegisterMessage(CUserAccount_GetAvailableValveDiscountPromotions_Response)
_sym_db.RegisterMessage(CUserAccount_GetAvailableValveDiscountPromotions_Response.ValveDiscountPromotionDetails)

CUserAccount_GetClientWalletDetails_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_GetClientWalletDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetClientWalletDetails_Request)
  })
_sym_db.RegisterMessage(CUserAccount_GetClientWalletDetails_Request)

CUserAccount_GetWalletDetails_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_GetWalletDetails_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETWALLETDETAILS_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetWalletDetails_Response)
  })
_sym_db.RegisterMessage(CUserAccount_GetWalletDetails_Response)

CUserAccount_GetAccountLinkStatus_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_GetAccountLinkStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetAccountLinkStatus_Request)
  })
_sym_db.RegisterMessage(CUserAccount_GetAccountLinkStatus_Request)

CUserAccount_GetAccountLinkStatus_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_GetAccountLinkStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetAccountLinkStatus_Response)
  })
_sym_db.RegisterMessage(CUserAccount_GetAccountLinkStatus_Response)

CUserAccount_CancelLicenseForApp_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_CancelLicenseForApp_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_CancelLicenseForApp_Request)
  })
_sym_db.RegisterMessage(CUserAccount_CancelLicenseForApp_Request)

CUserAccount_CancelLicenseForApp_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_CancelLicenseForApp_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_CancelLicenseForApp_Response)
  })
_sym_db.RegisterMessage(CUserAccount_CancelLicenseForApp_Response)

CUserAccount_GetUserCountry_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_GetUserCountry_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETUSERCOUNTRY_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetUserCountry_Request)
  })
_sym_db.RegisterMessage(CUserAccount_GetUserCountry_Request)

CUserAccount_GetUserCountry_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_GetUserCountry_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetUserCountry_Response)
  })
_sym_db.RegisterMessage(CUserAccount_GetUserCountry_Response)

CUserAccount_CreateFriendInviteToken_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_CreateFriendInviteToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_CreateFriendInviteToken_Request)
  })
_sym_db.RegisterMessage(CUserAccount_CreateFriendInviteToken_Request)

CUserAccount_CreateFriendInviteToken_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_CreateFriendInviteToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_CreateFriendInviteToken_Response)
  })
_sym_db.RegisterMessage(CUserAccount_CreateFriendInviteToken_Response)

CUserAccount_GetFriendInviteTokens_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_GetFriendInviteTokens_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetFriendInviteTokens_Request)
  })
_sym_db.RegisterMessage(CUserAccount_GetFriendInviteTokens_Request)

CUserAccount_GetFriendInviteTokens_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_GetFriendInviteTokens_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_GetFriendInviteTokens_Response)
  })
_sym_db.RegisterMessage(CUserAccount_GetFriendInviteTokens_Response)

CUserAccount_ViewFriendInviteToken_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_ViewFriendInviteToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_ViewFriendInviteToken_Request)
  })
_sym_db.RegisterMessage(CUserAccount_ViewFriendInviteToken_Request)

CUserAccount_ViewFriendInviteToken_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_ViewFriendInviteToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_ViewFriendInviteToken_Response)
  })
_sym_db.RegisterMessage(CUserAccount_ViewFriendInviteToken_Response)

CUserAccount_RedeemFriendInviteToken_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_RedeemFriendInviteToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RedeemFriendInviteToken_Request)
  })
_sym_db.RegisterMessage(CUserAccount_RedeemFriendInviteToken_Request)

CUserAccount_RedeemFriendInviteToken_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_RedeemFriendInviteToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RedeemFriendInviteToken_Response)
  })
_sym_db.RegisterMessage(CUserAccount_RedeemFriendInviteToken_Response)

CUserAccount_RevokeFriendInviteToken_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_RevokeFriendInviteToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RevokeFriendInviteToken_Request)
  })
_sym_db.RegisterMessage(CUserAccount_RevokeFriendInviteToken_Request)

CUserAccount_RevokeFriendInviteToken_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_RevokeFriendInviteToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RevokeFriendInviteToken_Response)
  })
_sym_db.RegisterMessage(CUserAccount_RevokeFriendInviteToken_Response)

CUserAccount_RegisterCompatTool_Request = _reflection.GeneratedProtocolMessageType('CUserAccount_RegisterCompatTool_Request', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RegisterCompatTool_Request)
  })
_sym_db.RegisterMessage(CUserAccount_RegisterCompatTool_Request)

CUserAccount_RegisterCompatTool_Response = _reflection.GeneratedProtocolMessageType('CUserAccount_RegisterCompatTool_Response', (_message.Message,), {
  'DESCRIPTOR' : _CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CUserAccount_RegisterCompatTool_Response)
  })
_sym_db.RegisterMessage(CUserAccount_RegisterCompatTool_Response)

CAccountLinking_GetLinkedAccountInfo_Request = _reflection.GeneratedProtocolMessageType('CAccountLinking_GetLinkedAccountInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CAccountLinking_GetLinkedAccountInfo_Request)
  })
_sym_db.RegisterMessage(CAccountLinking_GetLinkedAccountInfo_Request)

CAccountLinking_GetLinkedAccountInfo_Response = _reflection.GeneratedProtocolMessageType('CAccountLinking_GetLinkedAccountInfo_Response', (_message.Message,), {

  'CExternalAccountTuple_Response' : _reflection.GeneratedProtocolMessageType('CExternalAccountTuple_Response', (_message.Message,), {
    'DESCRIPTOR' : _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE,
    '__module__' : 'steammessages_useraccount_pb2'
    # @@protoc_insertion_point(class_scope:CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response)
    })
  ,
  'DESCRIPTOR' : _CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CAccountLinking_GetLinkedAccountInfo_Response)
  })
_sym_db.RegisterMessage(CAccountLinking_GetLinkedAccountInfo_Response)
_sym_db.RegisterMessage(CAccountLinking_GetLinkedAccountInfo_Response.CExternalAccountTuple_Response)

CEmbeddedClient_AuthorizeCurrentDevice_Request = _reflection.GeneratedProtocolMessageType('CEmbeddedClient_AuthorizeCurrentDevice_Request', (_message.Message,), {
  'DESCRIPTOR' : _CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CEmbeddedClient_AuthorizeCurrentDevice_Request)
  })
_sym_db.RegisterMessage(CEmbeddedClient_AuthorizeCurrentDevice_Request)

CEmbeddedClient_Token = _reflection.GeneratedProtocolMessageType('CEmbeddedClient_Token', (_message.Message,), {
  'DESCRIPTOR' : _CEMBEDDEDCLIENT_TOKEN,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CEmbeddedClient_Token)
  })
_sym_db.RegisterMessage(CEmbeddedClient_Token)

CEmbeddedClient_AuthorizeDevice_Response = _reflection.GeneratedProtocolMessageType('CEmbeddedClient_AuthorizeDevice_Response', (_message.Message,), {
  'DESCRIPTOR' : _CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE,
  '__module__' : 'steammessages_useraccount_pb2'
  # @@protoc_insertion_point(class_scope:CEmbeddedClient_AuthorizeDevice_Response)
  })
_sym_db.RegisterMessage(CEmbeddedClient_AuthorizeDevice_Response)


DESCRIPTOR._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST.fields_by_name['account_id']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST.fields_by_name['filter']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST.fields_by_name['return_access_token']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['external_id']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['external_user_name']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['external_url']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['access_token']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['access_token_secret']._options = None
_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE_CEXTERNALACCOUNTTUPLE_RESPONSE.fields_by_name['is_valid']._options = None

_USERACCOUNT = _descriptor.ServiceDescriptor(
  name='UserAccount',
  full_name='UserAccount',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030)A service to get user account information',
  create_key=_descriptor._internal_create_key,
  serialized_start=4539,
  serialized_end=6524,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAvailableValveDiscountPromotions',
    full_name='UserAccount.GetAvailableValveDiscountPromotions',
    index=0,
    containing_service=None,
    input_type=_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_REQUEST,
    output_type=_CUSERACCOUNT_GETAVAILABLEVALVEDISCOUNTPROMOTIONS_RESPONSE,
    serialized_options=b'\202\265\030>Gets the available promotional discounts available to the user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClientWalletDetails',
    full_name='UserAccount.GetClientWalletDetails',
    index=1,
    containing_service=None,
    input_type=_CUSERACCOUNT_GETCLIENTWALLETDETAILS_REQUEST,
    output_type=_CUSERACCOUNT_GETWALLETDETAILS_RESPONSE,
    serialized_options=b'\202\265\0302Returns balance and details about any users wallet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountLinkStatus',
    full_name='UserAccount.GetAccountLinkStatus',
    index=2,
    containing_service=None,
    input_type=_CUSERACCOUNT_GETACCOUNTLINKSTATUS_REQUEST,
    output_type=_CUSERACCOUNT_GETACCOUNTLINKSTATUS_RESPONSE,
    serialized_options=b'\202\265\030\033Fetches account link status',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelLicenseForApp',
    full_name='UserAccount.CancelLicenseForApp',
    index=3,
    containing_service=None,
    input_type=_CUSERACCOUNT_CANCELLICENSEFORAPP_REQUEST,
    output_type=_CUSERACCOUNT_CANCELLICENSEFORAPP_RESPONSE,
    serialized_options=b'\202\265\030!Cancels a free license for a user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserCountry',
    full_name='UserAccount.GetUserCountry',
    index=4,
    containing_service=None,
    input_type=_CUSERACCOUNT_GETUSERCOUNTRY_REQUEST,
    output_type=_CUSERACCOUNT_GETUSERCOUNTRY_RESPONSE,
    serialized_options=b'\202\265\030fGet the country code associated with the passed steamid (only available for logged-in user or support)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFriendInviteToken',
    full_name='UserAccount.CreateFriendInviteToken',
    index=5,
    containing_service=None,
    input_type=_CUSERACCOUNT_CREATEFRIENDINVITETOKEN_REQUEST,
    output_type=_CUSERACCOUNT_CREATEFRIENDINVITETOKEN_RESPONSE,
    serialized_options=b'\202\265\030FCreate a limited-use token that can be used to create a friend request',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFriendInviteTokens',
    full_name='UserAccount.GetFriendInviteTokens',
    index=6,
    containing_service=None,
    input_type=_CUSERACCOUNT_GETFRIENDINVITETOKENS_REQUEST,
    output_type=_CUSERACCOUNT_GETFRIENDINVITETOKENS_RESPONSE,
    serialized_options=b'\202\265\030)Get the set of active tokens for the user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ViewFriendInviteToken',
    full_name='UserAccount.ViewFriendInviteToken',
    index=7,
    containing_service=None,
    input_type=_CUSERACCOUNT_VIEWFRIENDINVITETOKEN_REQUEST,
    output_type=_CUSERACCOUNT_VIEWFRIENDINVITETOKEN_RESPONSE,
    serialized_options=b'\202\265\030#View details about an invite token ',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RedeemFriendInviteToken',
    full_name='UserAccount.RedeemFriendInviteToken',
    index=8,
    containing_service=None,
    input_type=_CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_REQUEST,
    output_type=_CUSERACCOUNT_REDEEMFRIENDINVITETOKEN_RESPONSE,
    serialized_options=b'\202\265\0309Create a friend relationship using the given invite token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeFriendInviteToken',
    full_name='UserAccount.RevokeFriendInviteToken',
    index=9,
    containing_service=None,
    input_type=_CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_REQUEST,
    output_type=_CUSERACCOUNT_REVOKEFRIENDINVITETOKEN_RESPONSE,
    serialized_options=b'\202\265\030$Revoke an active friend invite token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterCompatTool',
    full_name='UserAccount.RegisterCompatTool',
    index=10,
    containing_service=None,
    input_type=_CUSERACCOUNT_REGISTERCOMPATTOOL_REQUEST,
    output_type=_CUSERACCOUNT_REGISTERCOMPATTOOL_RESPONSE,
    serialized_options=b'\202\265\030)Register intended account usage of a tool',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERACCOUNT)

DESCRIPTOR.services_by_name['UserAccount'] = _USERACCOUNT


_ACCOUNTLINKING = _descriptor.ServiceDescriptor(
  name='AccountLinking',
  full_name='AccountLinking',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\0301A service to manage and link to external accounts',
  create_key=_descriptor._internal_create_key,
  serialized_start=6527,
  serialized_end=6812,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLinkedAccountInfo',
    full_name='AccountLinking.GetLinkedAccountInfo',
    index=0,
    containing_service=None,
    input_type=_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_REQUEST,
    output_type=_CACCOUNTLINKING_GETLINKEDACCOUNTINFO_RESPONSE,
    serialized_options=b'\202\265\030XList all my active linked external accounts; may be requested to return the access token',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTLINKING)

DESCRIPTOR.services_by_name['AccountLinking'] = _ACCOUNTLINKING


_EMBEDDEDCLIENT = _descriptor.ServiceDescriptor(
  name='EmbeddedClient',
  full_name='EmbeddedClient',
  file=DESCRIPTOR,
  index=2,
  serialized_options=b'\202\265\030JService to authorize and manage Steam functions directly embedded in games',
  create_key=_descriptor._internal_create_key,
  serialized_start=6815,
  serialized_end=7107,
  methods=[
  _descriptor.MethodDescriptor(
    name='AuthorizeCurrentDevice',
    full_name='EmbeddedClient.AuthorizeCurrentDevice',
    index=0,
    containing_service=None,
    input_type=_CEMBEDDEDCLIENT_AUTHORIZECURRENTDEVICE_REQUEST,
    output_type=_CEMBEDDEDCLIENT_AUTHORIZEDEVICE_RESPONSE,
    serialized_options=b'\202\265\030GUse a logged-in (password/etc) session to create a durable access token',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EMBEDDEDCLIENT)

DESCRIPTOR.services_by_name['EmbeddedClient'] = _EMBEDDEDCLIENT

UserAccount = service_reflection.GeneratedServiceType('UserAccount', (_service.Service,), dict(
  DESCRIPTOR = _USERACCOUNT,
  __module__ = 'steammessages_useraccount_pb2'
  ))

UserAccount_Stub = service_reflection.GeneratedServiceStubType('UserAccount_Stub', (UserAccount,), dict(
  DESCRIPTOR = _USERACCOUNT,
  __module__ = 'steammessages_useraccount_pb2'
  ))


AccountLinking = service_reflection.GeneratedServiceType('AccountLinking', (_service.Service,), dict(
  DESCRIPTOR = _ACCOUNTLINKING,
  __module__ = 'steammessages_useraccount_pb2'
  ))

AccountLinking_Stub = service_reflection.GeneratedServiceStubType('AccountLinking_Stub', (AccountLinking,), dict(
  DESCRIPTOR = _ACCOUNTLINKING,
  __module__ = 'steammessages_useraccount_pb2'
  ))


EmbeddedClient = service_reflection.GeneratedServiceType('EmbeddedClient', (_service.Service,), dict(
  DESCRIPTOR = _EMBEDDEDCLIENT,
  __module__ = 'steammessages_useraccount_pb2'
  ))

EmbeddedClient_Stub = service_reflection.GeneratedServiceStubType('EmbeddedClient_Stub', (EmbeddedClient,), dict(
  DESCRIPTOR = _EMBEDDEDCLIENT,
  __module__ = 'steammessages_useraccount_pb2'
  ))


# @@protoc_insertion_point(module_scope)



"""This module contains various value enumerations.

They are all based on :py:class:`IntEnum`, which gives them :py:class:`int` properties.
They can be compared to :py:class:`int` and used in places there :py:class:`int` is required.
Like for example, protobuf message.
They also provide a easy way to resolve a name or value for a specific enum.

.. code:: python

    >>> EResult.OK
    <EResult.OK: 1>
    >>> EResult(1)
    <EResult.OK: 1>
    >>> EResult['OK']
    <EResult.OK: 1>
    >>> EResult.OK == 1
    True

.. note::
    all enums from :py:mod:`steam.enum.common` can be imported directly from :py:mod:`steam.enum`
"""

from steam.enums.common import *
